# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations
from typing import *
from .options.AcquireActionRateOptions import AcquireActionRateOptions
from .options.AcquireActionRateModeIsDoubleOptions import AcquireActionRateModeIsDoubleOptions
from .options.AcquireActionRateModeIsBigOptions import AcquireActionRateModeIsBigOptions
from .enums.AcquireActionRateMode import AcquireActionRateMode


class AcquireActionRate:
    name: str
    mode: AcquireActionRateMode
    rates: Optional[List[float]] = None
    big_rates: Optional[List[str]] = None

    def __init__(
        self,
        name: str,
        mode: AcquireActionRateMode,
        options: Optional[AcquireActionRateOptions] = AcquireActionRateOptions(),
    ):
        self.name = name
        self.mode = mode
        self.rates = options.rates if options.rates else None
        self.big_rates = options.big_rates if options.big_rates else None

    @staticmethod
    def mode_is_double(
        name: str,
        rates: List[float],
        options: Optional[AcquireActionRateModeIsDoubleOptions] = AcquireActionRateModeIsDoubleOptions(),
    ) -> AcquireActionRate:
        return AcquireActionRate(
            name,
            AcquireActionRateMode.DOUBLE,
            AcquireActionRateOptions(
                rates,
            ),
        )

    @staticmethod
    def mode_is_big(
        name: str,
        big_rates: List[str],
        options: Optional[AcquireActionRateModeIsBigOptions] = AcquireActionRateModeIsBigOptions(),
    ) -> AcquireActionRate:
        return AcquireActionRate(
            name,
            AcquireActionRateMode.BIG,
            AcquireActionRateOptions(
                big_rates,
            ),
        )

    def properties(
        self,
    ) -> Dict[str, Any]:
        properties: Dict[str, Any] = {}

        if self.name is not None:
            properties["name"] = self.name
        if self.mode is not None:
            properties["mode"] = self.mode.value
        if self.rates is not None:
            properties["rates"] = self.rates
        if self.big_rates is not None:
            properties["bigRates"] = self.big_rates

        return properties



# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations
from typing import *
from .options.GooglePlayRealtimeNotificationMessageOptions import GooglePlayRealtimeNotificationMessageOptions


class GooglePlayRealtimeNotificationMessage:
    data: str
    message_id: str
    publish_time: str

    def __init__(
        self,
        data: str,
        message_id: str,
        publish_time: str,
        options: Optional[GooglePlayRealtimeNotificationMessageOptions] = GooglePlayRealtimeNotificationMessageOptions(),
    ):
        self.data = data
        self.message_id = message_id
        self.publish_time = publish_time

    def properties(
        self,
    ) -> Dict[str, Any]:
        properties: Dict[str, Any] = {}

        if self.data is not None:
            properties["data"] = self.data
        if self.message_id is not None:
            properties["messageId"] = self.message_id
        if self.publish_time is not None:
            properties["publishTime"] = self.publish_time

        return properties



# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations
from typing import *
from .options.SubscribeTransactionOptions import SubscribeTransactionOptions
from .enums.SubscribeTransactionStore import SubscribeTransactionStore
from .enums.SubscribeTransactionStatusDetail import SubscribeTransactionStatusDetail


class SubscribeTransaction:
    content_name: str
    transaction_id: str
    store: SubscribeTransactionStore
    status_detail: SubscribeTransactionStatusDetail
    expires_at: int
    user_id: Optional[str] = None
    last_allocated_at: Optional[int] = None
    last_take_over_at: Optional[int] = None
    revision: Optional[int] = None

    def __init__(
        self,
        content_name: str,
        transaction_id: str,
        store: SubscribeTransactionStore,
        status_detail: SubscribeTransactionStatusDetail,
        expires_at: int,
        options: Optional[SubscribeTransactionOptions] = SubscribeTransactionOptions(),
    ):
        self.content_name = content_name
        self.transaction_id = transaction_id
        self.store = store
        self.status_detail = status_detail
        self.expires_at = expires_at
        self.user_id = options.user_id if options.user_id else None
        self.last_allocated_at = options.last_allocated_at if options.last_allocated_at else None
        self.last_take_over_at = options.last_take_over_at if options.last_take_over_at else None
        self.revision = options.revision if options.revision else None

    def properties(
        self,
    ) -> Dict[str, Any]:
        properties: Dict[str, Any] = {}

        if self.content_name is not None:
            properties["contentName"] = self.content_name
        if self.transaction_id is not None:
            properties["transactionId"] = self.transaction_id
        if self.store is not None:
            properties["store"] = self.store.value
        if self.user_id is not None:
            properties["userId"] = self.user_id
        if self.status_detail is not None:
            properties["statusDetail"] = self.status_detail.value
        if self.expires_at is not None:
            properties["expiresAt"] = self.expires_at
        if self.last_allocated_at is not None:
            properties["lastAllocatedAt"] = self.last_allocated_at
        if self.last_take_over_at is not None:
            properties["lastTakeOverAt"] = self.last_take_over_at

        return properties



# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations
from typing import *
from .options.BatchResultPayloadOptions import BatchResultPayloadOptions


class BatchResultPayload:
    request_id: str
    status_code: int
    result_payload: str

    def __init__(
        self,
        request_id: str,
        status_code: int,
        result_payload: str,
        options: Optional[BatchResultPayloadOptions] = BatchResultPayloadOptions(),
    ):
        self.request_id = request_id
        self.status_code = status_code
        self.result_payload = result_payload

    def properties(
        self,
    ) -> Dict[str, Any]:
        properties: Dict[str, Any] = {}

        if self.request_id is not None:
            properties["requestId"] = self.request_id
        if self.status_code is not None:
            properties["statusCode"] = self.status_code
        if self.result_payload is not None:
            properties["resultPayload"] = self.result_payload

        return properties



# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations
from typing import *

from ...core.model import CdkResource, Stack
from ...core.func import GetAttr

from ..ref.StageRef import StageRef
from .enums.StageStatus import StageStatus

from .options.StageOptions import StageOptions


class Stage(CdkResource):
    stack: Stack
    owner_id: str
    name: str
    sort_number: int
    source_stage_name: Optional[str] = None

    def __init__(
        self,
        stack: Stack,
        owner_id: str,
        name: str,
        sort_number: int,
        options: Optional[StageOptions] = StageOptions(),
    ):
        super().__init__(
            "Freeze_Stage_" + name
        )

        self.stack = stack
        self.owner_id = owner_id
        self.name = name
        self.sort_number = sort_number
        self.source_stage_name = options.source_stage_name if options.source_stage_name else None
        stack.add_resource(
            self,
        )


    def alternate_keys(
        self,
    ):
        return "name"

    def resource_type(
        self,
    ) -> str:
        return "GS2::Freeze::Stage"

    def properties(
        self,
    ) -> Dict[str, Any]:
        properties: Dict[str, Any] = {}

        if self.owner_id is not None:
            properties["OwnerId"] = self.owner_id
        if self.name is not None:
            properties["Name"] = self.name
        if self.source_stage_name is not None:
            properties["SourceStageName"] = self.source_stage_name
        if self.sort_number is not None:
            properties["SortNumber"] = self.sort_number

        return properties

    def ref(
        self,
    ) -> StageRef:
        return StageRef(
            self.name,
        )

    def get_attr_stage_id(
        self,
    ) -> GetAttr:
        return GetAttr(
            self,
            "Item.StageId",
            None,
        )



# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations
from typing import *
from .options.AcquireActionResultOptions import AcquireActionResultOptions


class AcquireActionResult:
    action: str
    acquire_request: str
    status_code: Optional[int] = None
    acquire_result: Optional[str] = None

    def __init__(
        self,
        action: str,
        acquire_request: str,
        options: Optional[AcquireActionResultOptions] = AcquireActionResultOptions(),
    ):
        self.action = action
        self.acquire_request = acquire_request
        self.status_code = options.status_code if options.status_code else None
        self.acquire_result = options.acquire_result if options.acquire_result else None

    def properties(
        self,
    ) -> Dict[str, Any]:
        properties: Dict[str, Any] = {}

        if self.action is not None:
            properties["action"] = self.action.value
        if self.acquire_request is not None:
            properties["acquireRequest"] = self.acquire_request
        if self.status_code is not None:
            properties["statusCode"] = self.status_code
        if self.acquire_result is not None:
            properties["acquireResult"] = self.acquire_result

        return properties



# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations
from typing import *
from .options.ReceiptOptions import ReceiptOptions
from .enums.ReceiptStore import ReceiptStore


class Receipt:
    store: ReceiptStore
    transaction_i_d: str
    payload: str

    def __init__(
        self,
        store: ReceiptStore,
        transaction_i_d: str,
        payload: str,
        options: Optional[ReceiptOptions] = ReceiptOptions(),
    ):
        self.store = store
        self.transaction_i_d = transaction_i_d
        self.payload = payload

    def properties(
        self,
    ) -> Dict[str, Any]:
        properties: Dict[str, Any] = {}

        if self.store is not None:
            properties["store"] = self.store.value
        if self.transaction_i_d is not None:
            properties["transactionID"] = self.transaction_i_d
        if self.payload is not None:
            properties["payload"] = self.payload

        return properties



# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations
from typing import *
from .options.SendNotificationEntryOptions import SendNotificationEntryOptions


class SendNotificationEntry:
    user_id: str
    issuer: str
    subject: str
    payload: str
    enable_transfer_mobile_notification: bool
    sound: Optional[str] = None

    def __init__(
        self,
        user_id: str,
        issuer: str,
        subject: str,
        payload: str,
        enable_transfer_mobile_notification: bool,
        options: Optional[SendNotificationEntryOptions] = SendNotificationEntryOptions(),
    ):
        self.user_id = user_id
        self.issuer = issuer
        self.subject = subject
        self.payload = payload
        self.enable_transfer_mobile_notification = enable_transfer_mobile_notification
        self.sound = options.sound if options.sound else None

    def properties(
        self,
    ) -> Dict[str, Any]:
        properties: Dict[str, Any] = {}

        if self.user_id is not None:
            properties["userId"] = self.user_id
        if self.issuer is not None:
            properties["issuer"] = self.issuer
        if self.subject is not None:
            properties["subject"] = self.subject
        if self.payload is not None:
            properties["payload"] = self.payload
        if self.enable_transfer_mobile_notification is not None:
            properties["enableTransferMobileNotification"] = self.enable_transfer_mobile_notification
        if self.sound is not None:
            properties["sound"] = self.sound

        return properties



# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations
from typing import *
from .options.BlockingPolicyModelOptions import BlockingPolicyModelOptions
from .options.BlockingPolicyModelLocationDetectionIsEnableOptions import BlockingPolicyModelLocationDetectionIsEnableOptions
from .options.BlockingPolicyModelLocationDetectionIsDisableOptions import BlockingPolicyModelLocationDetectionIsDisableOptions
from .options.BlockingPolicyModelAnonymousIpDetectionIsEnableOptions import BlockingPolicyModelAnonymousIpDetectionIsEnableOptions
from .options.BlockingPolicyModelAnonymousIpDetectionIsDisableOptions import BlockingPolicyModelAnonymousIpDetectionIsDisableOptions
from .options.BlockingPolicyModelHostingProviderIpDetectionIsEnableOptions import BlockingPolicyModelHostingProviderIpDetectionIsEnableOptions
from .options.BlockingPolicyModelHostingProviderIpDetectionIsDisableOptions import BlockingPolicyModelHostingProviderIpDetectionIsDisableOptions
from .options.BlockingPolicyModelReputationIpDetectionIsEnableOptions import BlockingPolicyModelReputationIpDetectionIsEnableOptions
from .options.BlockingPolicyModelReputationIpDetectionIsDisableOptions import BlockingPolicyModelReputationIpDetectionIsDisableOptions
from .options.BlockingPolicyModelIpAddressesDetectionIsEnableOptions import BlockingPolicyModelIpAddressesDetectionIsEnableOptions
from .options.BlockingPolicyModelIpAddressesDetectionIsDisableOptions import BlockingPolicyModelIpAddressesDetectionIsDisableOptions
from .enums.BlockingPolicyModelDefaultRestriction import BlockingPolicyModelDefaultRestriction
from .enums.BlockingPolicyModelLocationDetection import BlockingPolicyModelLocationDetection
from .enums.BlockingPolicyModelLocationRestriction import BlockingPolicyModelLocationRestriction
from .enums.BlockingPolicyModelAnonymousIpDetection import BlockingPolicyModelAnonymousIpDetection
from .enums.BlockingPolicyModelAnonymousIpRestriction import BlockingPolicyModelAnonymousIpRestriction
from .enums.BlockingPolicyModelHostingProviderIpDetection import BlockingPolicyModelHostingProviderIpDetection
from .enums.BlockingPolicyModelHostingProviderIpRestriction import BlockingPolicyModelHostingProviderIpRestriction
from .enums.BlockingPolicyModelReputationIpDetection import BlockingPolicyModelReputationIpDetection
from .enums.BlockingPolicyModelReputationIpRestriction import BlockingPolicyModelReputationIpRestriction
from .enums.BlockingPolicyModelIpAddressesDetection import BlockingPolicyModelIpAddressesDetection
from .enums.BlockingPolicyModelIpAddressRestriction import BlockingPolicyModelIpAddressRestriction


class BlockingPolicyModel:
    pass_services: List[str]
    default_restriction: BlockingPolicyModelDefaultRestriction
    location_detection: BlockingPolicyModelLocationDetection
    anonymous_ip_detection: BlockingPolicyModelAnonymousIpDetection
    hosting_provider_ip_detection: BlockingPolicyModelHostingProviderIpDetection
    reputation_ip_detection: BlockingPolicyModelReputationIpDetection
    ip_addresses_detection: BlockingPolicyModelIpAddressesDetection
    locations: Optional[List[str]] = None
    location_restriction: Optional[BlockingPolicyModelLocationRestriction] = None
    anonymous_ip_restriction: Optional[BlockingPolicyModelAnonymousIpRestriction] = None
    hosting_provider_ip_restriction: Optional[BlockingPolicyModelHostingProviderIpRestriction] = None
    reputation_ip_restriction: Optional[BlockingPolicyModelReputationIpRestriction] = None
    ip_addresses: Optional[List[str]] = None
    ip_address_restriction: Optional[BlockingPolicyModelIpAddressRestriction] = None

    def __init__(
        self,
        pass_services: List[str],
        default_restriction: BlockingPolicyModelDefaultRestriction,
        location_detection: BlockingPolicyModelLocationDetection,
        anonymous_ip_detection: BlockingPolicyModelAnonymousIpDetection,
        hosting_provider_ip_detection: BlockingPolicyModelHostingProviderIpDetection,
        reputation_ip_detection: BlockingPolicyModelReputationIpDetection,
        ip_addresses_detection: BlockingPolicyModelIpAddressesDetection,
        options: Optional[BlockingPolicyModelOptions] = BlockingPolicyModelOptions(),
    ):
        self.pass_services = pass_services
        self.default_restriction = default_restriction
        self.location_detection = location_detection
        self.anonymous_ip_detection = anonymous_ip_detection
        self.hosting_provider_ip_detection = hosting_provider_ip_detection
        self.reputation_ip_detection = reputation_ip_detection
        self.ip_addresses_detection = ip_addresses_detection
        self.locations = options.locations if options.locations else None
        self.location_restriction = options.location_restriction if options.location_restriction else None
        self.anonymous_ip_restriction = options.anonymous_ip_restriction if options.anonymous_ip_restriction else None
        self.hosting_provider_ip_restriction = options.hosting_provider_ip_restriction if options.hosting_provider_ip_restriction else None
        self.reputation_ip_restriction = options.reputation_ip_restriction if options.reputation_ip_restriction else None
        self.ip_addresses = options.ip_addresses if options.ip_addresses else None
        self.ip_address_restriction = options.ip_address_restriction if options.ip_address_restriction else None

    @staticmethod
    def location_detection_is_enable(
        pass_services: List[str],
        default_restriction: BlockingPolicyModelDefaultRestriction,
        anonymous_ip_detection: BlockingPolicyModelAnonymousIpDetection,
        hosting_provider_ip_detection: BlockingPolicyModelHostingProviderIpDetection,
        reputation_ip_detection: BlockingPolicyModelReputationIpDetection,
        ip_addresses_detection: BlockingPolicyModelIpAddressesDetection,
        locations: List[str],
        location_restriction: BlockingPolicyModelLocationRestriction,
        options: Optional[BlockingPolicyModelLocationDetectionIsEnableOptions] = BlockingPolicyModelLocationDetectionIsEnableOptions(),
    ) -> BlockingPolicyModel:
        return BlockingPolicyModel(
            pass_services,
            default_restriction,
            BlockingPolicyModelLocationDetection.ENABLE,
            anonymous_ip_detection,
            hosting_provider_ip_detection,
            reputation_ip_detection,
            ip_addresses_detection,
            BlockingPolicyModelOptions(
                locations,
                location_restriction,
                options.ip_addresses,
            ),
        )

    @staticmethod
    def location_detection_is_disable(
        pass_services: List[str],
        default_restriction: BlockingPolicyModelDefaultRestriction,
        anonymous_ip_detection: BlockingPolicyModelAnonymousIpDetection,
        hosting_provider_ip_detection: BlockingPolicyModelHostingProviderIpDetection,
        reputation_ip_detection: BlockingPolicyModelReputationIpDetection,
        ip_addresses_detection: BlockingPolicyModelIpAddressesDetection,
        options: Optional[BlockingPolicyModelLocationDetectionIsDisableOptions] = BlockingPolicyModelLocationDetectionIsDisableOptions(),
    ) -> BlockingPolicyModel:
        return BlockingPolicyModel(
            pass_services,
            default_restriction,
            BlockingPolicyModelLocationDetection.DISABLE,
            anonymous_ip_detection,
            hosting_provider_ip_detection,
            reputation_ip_detection,
            ip_addresses_detection,
            BlockingPolicyModelOptions(
                options.ip_addresses,
            ),
        )

    @staticmethod
    def anonymous_ip_detection_is_enable(
        pass_services: List[str],
        default_restriction: BlockingPolicyModelDefaultRestriction,
        location_detection: BlockingPolicyModelLocationDetection,
        hosting_provider_ip_detection: BlockingPolicyModelHostingProviderIpDetection,
        reputation_ip_detection: BlockingPolicyModelReputationIpDetection,
        ip_addresses_detection: BlockingPolicyModelIpAddressesDetection,
        anonymous_ip_restriction: BlockingPolicyModelAnonymousIpRestriction,
        options: Optional[BlockingPolicyModelAnonymousIpDetectionIsEnableOptions] = BlockingPolicyModelAnonymousIpDetectionIsEnableOptions(),
    ) -> BlockingPolicyModel:
        return BlockingPolicyModel(
            pass_services,
            default_restriction,
            location_detection,
            BlockingPolicyModelAnonymousIpDetection.ENABLE,
            hosting_provider_ip_detection,
            reputation_ip_detection,
            ip_addresses_detection,
            BlockingPolicyModelOptions(
                anonymous_ip_restriction,
                options.ip_addresses,
            ),
        )

    @staticmethod
    def anonymous_ip_detection_is_disable(
        pass_services: List[str],
        default_restriction: BlockingPolicyModelDefaultRestriction,
        location_detection: BlockingPolicyModelLocationDetection,
        hosting_provider_ip_detection: BlockingPolicyModelHostingProviderIpDetection,
        reputation_ip_detection: BlockingPolicyModelReputationIpDetection,
        ip_addresses_detection: BlockingPolicyModelIpAddressesDetection,
        options: Optional[BlockingPolicyModelAnonymousIpDetectionIsDisableOptions] = BlockingPolicyModelAnonymousIpDetectionIsDisableOptions(),
    ) -> BlockingPolicyModel:
        return BlockingPolicyModel(
            pass_services,
            default_restriction,
            location_detection,
            BlockingPolicyModelAnonymousIpDetection.DISABLE,
            hosting_provider_ip_detection,
            reputation_ip_detection,
            ip_addresses_detection,
            BlockingPolicyModelOptions(
                options.ip_addresses,
            ),
        )

    @staticmethod
    def hosting_provider_ip_detection_is_enable(
        pass_services: List[str],
        default_restriction: BlockingPolicyModelDefaultRestriction,
        location_detection: BlockingPolicyModelLocationDetection,
        anonymous_ip_detection: BlockingPolicyModelAnonymousIpDetection,
        reputation_ip_detection: BlockingPolicyModelReputationIpDetection,
        ip_addresses_detection: BlockingPolicyModelIpAddressesDetection,
        hosting_provider_ip_restriction: BlockingPolicyModelHostingProviderIpRestriction,
        options: Optional[BlockingPolicyModelHostingProviderIpDetectionIsEnableOptions] = BlockingPolicyModelHostingProviderIpDetectionIsEnableOptions(),
    ) -> BlockingPolicyModel:
        return BlockingPolicyModel(
            pass_services,
            default_restriction,
            location_detection,
            anonymous_ip_detection,
            BlockingPolicyModelHostingProviderIpDetection.ENABLE,
            reputation_ip_detection,
            ip_addresses_detection,
            BlockingPolicyModelOptions(
                hosting_provider_ip_restriction,
                options.ip_addresses,
            ),
        )

    @staticmethod
    def hosting_provider_ip_detection_is_disable(
        pass_services: List[str],
        default_restriction: BlockingPolicyModelDefaultRestriction,
        location_detection: BlockingPolicyModelLocationDetection,
        anonymous_ip_detection: BlockingPolicyModelAnonymousIpDetection,
        reputation_ip_detection: BlockingPolicyModelReputationIpDetection,
        ip_addresses_detection: BlockingPolicyModelIpAddressesDetection,
        options: Optional[BlockingPolicyModelHostingProviderIpDetectionIsDisableOptions] = BlockingPolicyModelHostingProviderIpDetectionIsDisableOptions(),
    ) -> BlockingPolicyModel:
        return BlockingPolicyModel(
            pass_services,
            default_restriction,
            location_detection,
            anonymous_ip_detection,
            BlockingPolicyModelHostingProviderIpDetection.DISABLE,
            reputation_ip_detection,
            ip_addresses_detection,
            BlockingPolicyModelOptions(
                options.ip_addresses,
            ),
        )

    @staticmethod
    def reputation_ip_detection_is_enable(
        pass_services: List[str],
        default_restriction: BlockingPolicyModelDefaultRestriction,
        location_detection: BlockingPolicyModelLocationDetection,
        anonymous_ip_detection: BlockingPolicyModelAnonymousIpDetection,
        hosting_provider_ip_detection: BlockingPolicyModelHostingProviderIpDetection,
        ip_addresses_detection: BlockingPolicyModelIpAddressesDetection,
        reputation_ip_restriction: BlockingPolicyModelReputationIpRestriction,
        options: Optional[BlockingPolicyModelReputationIpDetectionIsEnableOptions] = BlockingPolicyModelReputationIpDetectionIsEnableOptions(),
    ) -> BlockingPolicyModel:
        return BlockingPolicyModel(
            pass_services,
            default_restriction,
            location_detection,
            anonymous_ip_detection,
            hosting_provider_ip_detection,
            BlockingPolicyModelReputationIpDetection.ENABLE,
            ip_addresses_detection,
            BlockingPolicyModelOptions(
                reputation_ip_restriction,
                options.ip_addresses,
            ),
        )

    @staticmethod
    def reputation_ip_detection_is_disable(
        pass_services: List[str],
        default_restriction: BlockingPolicyModelDefaultRestriction,
        location_detection: BlockingPolicyModelLocationDetection,
        anonymous_ip_detection: BlockingPolicyModelAnonymousIpDetection,
        hosting_provider_ip_detection: BlockingPolicyModelHostingProviderIpDetection,
        ip_addresses_detection: BlockingPolicyModelIpAddressesDetection,
        options: Optional[BlockingPolicyModelReputationIpDetectionIsDisableOptions] = BlockingPolicyModelReputationIpDetectionIsDisableOptions(),
    ) -> BlockingPolicyModel:
        return BlockingPolicyModel(
            pass_services,
            default_restriction,
            location_detection,
            anonymous_ip_detection,
            hosting_provider_ip_detection,
            BlockingPolicyModelReputationIpDetection.DISABLE,
            ip_addresses_detection,
            BlockingPolicyModelOptions(
                options.ip_addresses,
            ),
        )

    @staticmethod
    def ip_addresses_detection_is_enable(
        pass_services: List[str],
        default_restriction: BlockingPolicyModelDefaultRestriction,
        location_detection: BlockingPolicyModelLocationDetection,
        anonymous_ip_detection: BlockingPolicyModelAnonymousIpDetection,
        hosting_provider_ip_detection: BlockingPolicyModelHostingProviderIpDetection,
        reputation_ip_detection: BlockingPolicyModelReputationIpDetection,
        ip_address_restriction: BlockingPolicyModelIpAddressRestriction,
        options: Optional[BlockingPolicyModelIpAddressesDetectionIsEnableOptions] = BlockingPolicyModelIpAddressesDetectionIsEnableOptions(),
    ) -> BlockingPolicyModel:
        return BlockingPolicyModel(
            pass_services,
            default_restriction,
            location_detection,
            anonymous_ip_detection,
            hosting_provider_ip_detection,
            reputation_ip_detection,
            BlockingPolicyModelIpAddressesDetection.ENABLE,
            BlockingPolicyModelOptions(
                ip_address_restriction,
                options.ip_addresses,
            ),
        )

    @staticmethod
    def ip_addresses_detection_is_disable(
        pass_services: List[str],
        default_restriction: BlockingPolicyModelDefaultRestriction,
        location_detection: BlockingPolicyModelLocationDetection,
        anonymous_ip_detection: BlockingPolicyModelAnonymousIpDetection,
        hosting_provider_ip_detection: BlockingPolicyModelHostingProviderIpDetection,
        reputation_ip_detection: BlockingPolicyModelReputationIpDetection,
        options: Optional[BlockingPolicyModelIpAddressesDetectionIsDisableOptions] = BlockingPolicyModelIpAddressesDetectionIsDisableOptions(),
    ) -> BlockingPolicyModel:
        return BlockingPolicyModel(
            pass_services,
            default_restriction,
            location_detection,
            anonymous_ip_detection,
            hosting_provider_ip_detection,
            reputation_ip_detection,
            BlockingPolicyModelIpAddressesDetection.DISABLE,
            BlockingPolicyModelOptions(
                options.ip_addresses,
            ),
        )

    def properties(
        self,
    ) -> Dict[str, Any]:
        properties: Dict[str, Any] = {}

        if self.pass_services is not None:
            properties["passServices"] = self.pass_services
        if self.default_restriction is not None:
            properties["defaultRestriction"] = self.default_restriction.value
        if self.location_detection is not None:
            properties["locationDetection"] = self.location_detection.value
        if self.locations is not None:
            properties["locations"] = self.locations
        if self.location_restriction is not None:
            properties["locationRestriction"] = self.location_restriction.value
        if self.anonymous_ip_detection is not None:
            properties["anonymousIpDetection"] = self.anonymous_ip_detection.value
        if self.anonymous_ip_restriction is not None:
            properties["anonymousIpRestriction"] = self.anonymous_ip_restriction.value
        if self.hosting_provider_ip_detection is not None:
            properties["hostingProviderIpDetection"] = self.hosting_provider_ip_detection.value
        if self.hosting_provider_ip_restriction is not None:
            properties["hostingProviderIpRestriction"] = self.hosting_provider_ip_restriction.value
        if self.reputation_ip_detection is not None:
            properties["reputationIpDetection"] = self.reputation_ip_detection.value
        if self.reputation_ip_restriction is not None:
            properties["reputationIpRestriction"] = self.reputation_ip_restriction.value
        if self.ip_addresses_detection is not None:
            properties["ipAddressesDetection"] = self.ip_addresses_detection.value
        if self.ip_addresses is not None:
            properties["ipAddresses"] = self.ip_addresses
        if self.ip_address_restriction is not None:
            properties["ipAddressRestriction"] = self.ip_address_restriction.value

        return properties



# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations
from typing import *
from .AppleAppStoreSubscriptionContent import AppleAppStoreSubscriptionContent
from .GooglePlaySubscriptionContent import GooglePlaySubscriptionContent
from .options.StoreSubscriptionContentModelOptions import StoreSubscriptionContentModelOptions
from .options.StoreSubscriptionContentModelTriggerExtendModeIsJustOptions import StoreSubscriptionContentModelTriggerExtendModeIsJustOptions
from .options.StoreSubscriptionContentModelTriggerExtendModeIsRollupHourOptions import StoreSubscriptionContentModelTriggerExtendModeIsRollupHourOptions
from .enums.StoreSubscriptionContentModelTriggerExtendMode import StoreSubscriptionContentModelTriggerExtendMode


class StoreSubscriptionContentModel:
    name: str
    schedule_namespace_id: str
    trigger_name: str
    trigger_extend_mode: StoreSubscriptionContentModelTriggerExtendMode
    reallocate_span_days: int
    metadata: Optional[str] = None
    rollup_hour: Optional[int] = None
    apple_app_store: Optional[AppleAppStoreSubscriptionContent] = None
    google_play: Optional[GooglePlaySubscriptionContent] = None

    def __init__(
        self,
        name: str,
        schedule_namespace_id: str,
        trigger_name: str,
        trigger_extend_mode: StoreSubscriptionContentModelTriggerExtendMode,
        reallocate_span_days: int,
        options: Optional[StoreSubscriptionContentModelOptions] = StoreSubscriptionContentModelOptions(),
    ):
        self.name = name
        self.schedule_namespace_id = schedule_namespace_id
        self.trigger_name = trigger_name
        self.trigger_extend_mode = trigger_extend_mode
        self.reallocate_span_days = reallocate_span_days
        self.metadata = options.metadata if options.metadata else None
        self.rollup_hour = options.rollup_hour if options.rollup_hour else None
        self.apple_app_store = options.apple_app_store if options.apple_app_store else None
        self.google_play = options.google_play if options.google_play else None

    @staticmethod
    def trigger_extend_mode_is_just(
        name: str,
        schedule_namespace_id: str,
        trigger_name: str,
        reallocate_span_days: int,
        options: Optional[StoreSubscriptionContentModelTriggerExtendModeIsJustOptions] = StoreSubscriptionContentModelTriggerExtendModeIsJustOptions(),
    ) -> StoreSubscriptionContentModel:
        return StoreSubscriptionContentModel(
            name,
            schedule_namespace_id,
            trigger_name,
            StoreSubscriptionContentModelTriggerExtendMode.JUST,
            reallocate_span_days,
            StoreSubscriptionContentModelOptions(
                options.metadata,
                options.apple_app_store,
                options.google_play,
            ),
        )

    @staticmethod
    def trigger_extend_mode_is_rollup_hour(
        name: str,
        schedule_namespace_id: str,
        trigger_name: str,
        reallocate_span_days: int,
        rollup_hour: int,
        options: Optional[StoreSubscriptionContentModelTriggerExtendModeIsRollupHourOptions] = StoreSubscriptionContentModelTriggerExtendModeIsRollupHourOptions(),
    ) -> StoreSubscriptionContentModel:
        return StoreSubscriptionContentModel(
            name,
            schedule_namespace_id,
            trigger_name,
            StoreSubscriptionContentModelTriggerExtendMode.ROLLUP_HOUR,
            reallocate_span_days,
            StoreSubscriptionContentModelOptions(
                rollup_hour,
                options.metadata,
                options.apple_app_store,
                options.google_play,
            ),
        )

    def properties(
        self,
    ) -> Dict[str, Any]:
        properties: Dict[str, Any] = {}

        if self.name is not None:
            properties["name"] = self.name
        if self.metadata is not None:
            properties["metadata"] = self.metadata
        if self.schedule_namespace_id is not None:
            properties["scheduleNamespaceId"] = self.schedule_namespace_id
        if self.trigger_name is not None:
            properties["triggerName"] = self.trigger_name
        if self.trigger_extend_mode is not None:
            properties["triggerExtendMode"] = self.trigger_extend_mode.value
        if self.rollup_hour is not None:
            properties["rollupHour"] = self.rollup_hour
        if self.reallocate_span_days is not None:
            properties["reallocateSpanDays"] = self.reallocate_span_days
        if self.apple_app_store is not None:
            properties["appleAppStore"] = self.apple_app_store.properties(
            )
        if self.google_play is not None:
            properties["googlePlay"] = self.google_play.properties(
            )

        return properties
